#import "BMIController.h"

@implementation BMIController

- (void)awakeFromNib
{
	NSNotificationCenter	*aCenter=[NSNotificationCenter defaultCenter];
    [aCenter addObserver:NSApp
                selector:@selector(terminate:)
                name:@"NSWindowWillCloseNotification"
                object:bmiWindow];
    [aCenter addObserver:self
                selector:@selector(applicationWillTerminate:)
                name:@"NSApplicationWillTerminateNotification"
                object:NSApp];

	//初期設定の保存
	[self loadUserDefaults];

	//BMIを計算して結果をすべてのコントロールにセット
	[self calcBMIAndSet];
}

- (void)applicationWillTerminate:(NSNotification *)pNotification
{
	//初期設定の保存
	[self saveUserDefaults];
}


#pragma mark -
#pragma mark ----- 初期設定の処理 -----
//初期設定の読み込み	
- (void)loadUserDefaults
{
    NSUserDefaults  *aDefault=[NSUserDefaults standardUserDefaults];
    if([aDefault floatForKey:@"height"])
		height=[aDefault floatForKey:@"height"];
	else
		height=[heightField floatValue];
		
    if([aDefault floatForKey:@"weight"])
		weight=[aDefault floatForKey:@"weight"];
	else
		weight=[weightField floatValue];
}

//初期設定の保存
- (void)saveUserDefaults
{
	NSUserDefaults  *aDefault=[NSUserDefaults standardUserDefaults];
	[aDefault setFloat:height forKey:@"height"];
	[aDefault setFloat:weight forKey:@"weight"];
	[aDefault synchronize];
}


#pragma mark -
#pragma mark ----- データ変更の受け取りと計算結果の表示 -----
- (IBAction)changeBMI:(id)sender
{
	bmi=[sender floatValue];
	[self calcWeightAndSet];
}
- (IBAction)changeHeight:(id)sender
{
	height=[sender floatValue];
	[self calcBMIAndSet];
}
- (IBAction)changeWeight:(id)sender
{
	weight=[sender floatValue];
	[self calcBMIAndSet];
}

- (void)calcWeightAndSet
{
	weight=calculateWeight(height, bmi);	
	[self setValues];
}
- (void)calcBMIAndSet
{
	bmi=calculateBMI(height, weight);	
	[self setValues];
}


- (void)setValues
{
	[bmiField setFloatValue:bmi];
    [bmiSlider setFloatValue:bmi];
	
    [heightField setFloatValue:height];
    [heightSlider setFloatValue:height];
	
    [weightField setFloatValue:weight];
    [weightSlider setFloatValue:weight];
}


#pragma mark -
#pragma mark ----- BMI計算処理 -----
//体重を逆算する
float calculateWeight(float pHeight, float pBMI)
{
	return pBMI*(pHeight/100)*(pHeight/100);
}

//BMIの計算
float calculateBMI(float pHeight, float pWeight)
{
	return pWeight/(pHeight/100)/(pHeight/100);
}

@end
